import tableHelpers from '../../utils/tableHelper.js'; // Caminho para o helper
import API from '../../api/api.js'; // Função para pegar as contas de cassino
import Utils from '../utils.js';

async function displayCasinoAccountsTable() {
    const data = (await API.fetchCasinoAccounts()).result;
    const tableBody = document.querySelector('#dataTable-casinoaccounts tbody');
    tableBody.innerHTML = '';

    if (!data || data.length === 0) return;

    data.sort((a, b) => {
        if (a.status === "PENDING" && b.status !== "PENDING") return -1;
        if (a.status !== "PENDING" && b.status === "PENDING") return 1;
        return b.account_id - a.account_id; // Ordena por ID se os status forem iguais
    });

    const fragment = document.createDocumentFragment();

    data.forEach((account) => {
        const row = document.createElement('tr');
        row.dataset.id = account.account_id;

        // Células de dados
        row.appendChild(tableHelpers.createCell(account.account_id));
        row.appendChild(tableHelpers.createCell(account.username));
        row.appendChild(tableHelpers.createCell(account.casino_name));
        row.appendChild(tableHelpers.createCell(account.account_username));

        // Célula de senha com botão de alternar
        const passwordCell = document.createElement('td');
        const passwordWrapper = document.createElement('div');
        passwordWrapper.classList.add('password-container');

        const passwordSpan = document.createElement('span');
        passwordSpan.classList.add('password');
        passwordSpan.textContent = '••••';

        const toggleButton = document.createElement('button');
        toggleButton.classList.add('toggle-password-btn');
        toggleButton.dataset.id = account.account_id;
        toggleButton.setAttribute('aria-label', 'Mostrar senha');

        const eyeIcon = document.createElement('i');
        eyeIcon.classList.add('fa', 'fa-eye');
        toggleButton.appendChild(eyeIcon);

        passwordWrapper.appendChild(passwordSpan);
        passwordWrapper.appendChild(toggleButton);
        passwordCell.appendChild(passwordWrapper);

        row.appendChild(passwordCell);
        row.appendChild(tableHelpers.createCell(tableHelpers.formatDate(account.birth_date)));
        row.appendChild(tableHelpers.createCell(account.status));

        // Botões de ação (Delete e Verify)
        const deleteButton = tableHelpers.createActionCell('delete-btn', account.account_id);
        row.appendChild(deleteButton);

        if (account.status === 'PENDING') {
            const verifyButton = tableHelpers.createActionCell('verify-btn', account.account_id);
            row.appendChild(verifyButton);
        }

        fragment.appendChild(row);
    });

    tableBody.appendChild(fragment);
    //tableBody.dataset.accounts = JSON.stringify(data);
    // Delegação de eventos
    setupEventListeners(tableBody, data);
}

function setupEventListeners(tableBody, data) {
    tableBody.addEventListener('click', (event) => {
        const tr = event.target.closest('tr');
        if (!tr) return;

        const accountId = tr.dataset.id;

        if (event.target.matches('.delete-btn,  .delete-btn i')) {
            Utils.deleteCasinoAccount(accountId, event);
        }

        if (event.target.matches('.verify-btn, .verify-btn i')) {
            Utils.verifyCasinoAccount(accountId, event);
        }

        if (event.target.matches('.toggle-password-btn, .toggle-password-btn i')) {
            const passwordSpan = tr.querySelector('.password');
            const account = data.find(acc => acc.account_id == accountId);
            if (!account) return;

            const isHidden = passwordSpan.textContent === '••••';
            passwordSpan.textContent = isHidden ? account.decrypted_password : '••••';

            const icon = tr.querySelector('.toggle-password-btn i');
            icon.classList.toggle('fa-eye');
            icon.classList.toggle('fa-eye-slash');
        }
    });
}

export default displayCasinoAccountsTable;