import tableHelpers from '../../utils/tableHelper.js'; // Caminho correto após a mudança
import API from '../../api/api.js'
import Utils from '../utils.js';

async function displayDebtsTable() {
    const debts = (await API.fetchDebts()).result;
    const tableBodyPending = document.getElementById('dataTable-sends').querySelector('tbody');
    tableBodyPending.innerHTML = '';


    if (!debts || debts.length === 0) {
        return console.error("Nenhum dado encontrado");
    }

    debts.sort((a, b) => {
        if (a.status === "UNPAID" && b.status !== "UNPAID") return -1;
        if (a.status !== "UNPAID" && b.status === "UNPAID") return 1;
        return b.debt_id - a.debt_id; // Ordena por ID se os status forem iguais
    });

    const fragment = document.createDocumentFragment();

    debts.forEach((debt) => {
        const row = tableHelpers.createTableRow(debt.debt_id);
        row.appendChild(tableHelpers.createCell(debt.user_id));
        row.appendChild(tableHelpers.createCell(debt.username));
        row.appendChild(tableHelpers.createCell(debt.amount + "€"));
        row.appendChild(tableHelpers.createCell(debt.status));
        row.appendChild(tableHelpers.createCell(tableHelpers.formatDate(debt.created_at)));
        
        const cellButton = tableHelpers.createActionCell('delete-btn', debt.debt_id);
        row.appendChild(cellButton);

        if(debt.status == "UNPAID") {
            const verifyButton = tableHelpers.createActionCell('verify-btn', debt.debt_id);
            row.appendChild(verifyButton);
        }

        fragment.appendChild(row);
    });

    tableBodyPending.appendChild(fragment);

    // Delegação de eventos
    setupEventListeners(tableBodyPending);
}

function setupEventListeners(tableBody) {
    tableBody.addEventListener('click', (event) => {
        const tr = event.target.closest('tr');
        if (!tr) return;

        const debtId = tr.dataset.id;

        if (event.target.matches('.delete-btn,  .delete-btn i')) {
            Utils.deleteDebt(debtId, event);
        }

        if (event.target.matches('.verify-btn, .verify-btn i')) {
            Utils.updateDebt(debtId, event);
        }
    });
}


export default displayDebtsTable;
