import tableHelpers from '../../utils/tableHelper.js'; // Caminho correto após a mudança
import API from '../../api/api.js'
import Utils from '../utils.js';

async function displayUsersTable() {
    const users = (await API.fetchUsers()).result;
    const tableBodyPending = document.getElementById('dataTable-accounts').querySelector('tbody');
    tableBodyPending.innerHTML = '';

    if (!users || users.length === 0) {
        return console.error("Nenhum dado encontrado");
    }

    users.sort((a, b) => b.user_id - a.user_id);

    const fragment = document.createDocumentFragment();

    users.forEach((account) => {
        const row = tableHelpers.createTableRow(account.user_id);
        row.appendChild(tableHelpers.createCell(account.user_id, "user_id"));
        row.appendChild(tableHelpers.createCell(account.username, "username"));
        row.appendChild(tableHelpers.createCell(account.balance, "balance"));
        row.appendChild(tableHelpers.createCell(tableHelpers.formatDate(account.created_at), "created_at"));

        const cellButton = tableHelpers.createActionCell('delete-btn', account.user_id);
        row.appendChild(cellButton);

        fragment.appendChild(row);
    });

    tableBodyPending.appendChild(fragment);

    // Delegação de eventos
    setupEventListeners(tableBodyPending);
}

function setupEventListeners(tableBody) {
    tableBody.addEventListener('click', function(event) {
        const tr = event.target.closest('tr');
        if (!tr) return;
        
        if (event.target && event.target.matches('.delete-btn, .delete-btn i')) {
            const user_id = tr.dataset.id;
            Utils.deleteUser(user_id, event);
        }
    });

    document.getElementById('confirm-add-saldo-button').addEventListener('click', function(event) {
        try {
            const checkedBoxes = Array.from(tableBody.querySelectorAll('.checkbox-acc')).filter(checkbox => checkbox.checked);
            const amount = parseFloat(document.getElementById('saldoInput').value);
            if(checkedBoxes.length === 0) {
                throw new Error("Selecione pelo menos um utilizador.");
            }
            if( !amount || isNaN(amount) || amount <= 0) {
                throw new Error("Insira um valor válido.");
            }
            checkedBoxes.forEach(checkbox => {
                Utils.addUserBonus(checkbox.dataset.id, amount);
            });
            for(const checkbox of checkedBoxes) {
                const balanceElement = checkbox.closest('tr').querySelector('[data-name="balance"]');
                if(balanceElement) balanceElement.textContent = parseFloat(balanceElement.textContent) + amount;
                checkbox.checked = false;
            }
            document.getElementById('saldoInput').value = '';
        } catch (error) {
            console.error("Erro ao adicionar saldo bónus:", error);
            Utils.showToast("Erro ao adicionar saldo bónus.", "error");
        }
    })
}

export default displayUsersTable;
