import tableHelpers from '../../utils/tableHelper.js'; // Caminho correto após a mudança
import API from '../../api/api.js'
import Utils from '../utils.js'

async function displayWithdrawalsTable() {
    const withdrawals = (await API.fetchWithdrawals()).result;
    const tableBodyPending = document.getElementById('dataTable-withdraws').querySelector('tbody');
    tableBodyPending.innerHTML = '';


    if (!withdrawals || withdrawals.length === 0) {
        return console.error("Nenhum dado encontrado");
    }

    withdrawals.sort((a, b) => {
        if (a.status === "PENDING" && b.status !== "PENDING") return -1;
        if (a.status !== "PENDING" && b.status === "PENDING") return 1;
        return b.withdrawal_id - a.withdrawal_id; // Ordena por ID se os status forem iguais
    });

    const fragment = document.createDocumentFragment();

    withdrawals.forEach((withdrawal) => {
        const row = tableHelpers.createTableRow(withdrawal.withdrawal_id);
        row.appendChild(tableHelpers.createCell(withdrawal.withdrawal_id));
        row.appendChild(tableHelpers.createCell(withdrawal.username));
        row.appendChild(tableHelpers.createCell(withdrawal.amount + "€"));
        row.appendChild(tableHelpers.createCell(withdrawal.status));
        row.appendChild(tableHelpers.createCell(tableHelpers.formatDate(withdrawal.created_at)));
        
        const cellButton = tableHelpers.createActionCell('delete-btn', withdrawal.debt_id);
        row.appendChild(cellButton);

        if(withdrawal.status == "PENDING") {
            const verifyButton = tableHelpers.createActionCell('verify-btn', withdrawal.debt_id);
            row.appendChild(verifyButton);
        }

        fragment.appendChild(row);
    });

    tableBodyPending.appendChild(fragment);

    // Delegação de eventos
    setupEventListeners(tableBodyPending);
}

function setupEventListeners(tableBody) {
    tableBody.addEventListener('click', (event) => {
        const tr = event.target.closest('tr');
        if (!tr) return;

        const withdrawalId = tr.dataset.id;

        if (event.target.matches('.delete-btn,  .delete-btn i')) {
            Utils.deleteWithdrawal(withdrawalId, event)
        }

        if (event.target.matches('.verify-btn, .verify-btn i')) {
            Utils.updateWithdrawal(withdrawalId, event)
        }
    });
}


export default displayWithdrawalsTable;
