import API from '../api/api.js'


const Utils = {
    deleteUser:  async (user_id, event) => {
        Utils.showConfirmationModal(
            "Tem certeza que deseja excluir este usuário?",
            "Esta ação não pode ser desfeita.",
            async () => {
                try {
                    const request = await API.deleteUser(user_id); // Chama a API para deletar o usuário
                    if(!request.success) {
                        throw new Error(request.message);
                    }
                    const tr = event.target.closest('tr');
                    if (tr) tr.remove(); // Remove a linha da tabela
                    Utils.showToast("Usuário deletado com sucesso!", "success");
                } catch (error) {
                    console.error("Erro ao deletar usuário:", error);
                    Utils.showToast("Erro ao deletar usuário.", "error");
                }
            }
        );
    },

    deleteDebt: async (debt_id, event) => {
        Utils.showConfirmationModal(
            "Tem certeza que deseja excluir este debt?",
            "Esta ação não pode ser desfeita.",
            async () => {
                try {
                    const request = await API.deleteDebt(debt_id); // Chama a API para deletar o usuário
                    if(!request.success) {
                        throw new Error(request.message);
                    }
                    const tr = event.target.closest('tr');
                    if (tr) tr.remove(); // Remove a linha da tabela
                    Utils.showToast("Debt apagado com sucesso!", "success");
                } catch (error) {
                    console.error("Erro ao apagar usuário:", error);
                    Utils.showToast("Erro ao apagar usuário.", "error");
                }
            }
        );
    },

    deleteCasinoAccount: async (account_id, event) => {
        Utils.showConfirmationModal(
            "Tem certeza que deseja excluir a conta de casino?",
            "Esta ação não pode ser desfeita.",
            async () => {
                try {
                    const request = await API.deleteCasinoAccount(account_id); // Chama a API para deletar o usuário
                    if(!request.success) {
                        throw new Error(request.message);
                    }
                    const tr = event.target.closest('tr');
                    if (tr) tr.remove(); // Remove a linha da tabela
                    Utils.showToast("Conta apagada com sucesso!", "success");
                } catch (error) {
                    console.error("Erro ao apagar conta de casino:", error);
                    Utils.showToast("Erro ao apagar conta de casino.", "error");
                }
            }
        );
    },
    
    deleteWithdrawal: async (withdrawal_id, event) => {
        Utils.showConfirmationModal(
            "Tem certeza que deseja excluir este levantamento?",
            "Esta ação não pode ser desfeita.",
            async () => {
                try {
                    const request = await API.deleteWithdrawal(withdrawal_id); // Chama a API para deletar o usuário
                    if(!request.success) {
                        throw new Error(request.message);
                    }
                    const tr = event.target.closest('tr');
                    if (tr) tr.remove(); // Remove a linha da tabela
                    Utils.showToast("Levantamento apagado com sucesso!", "success");
                } catch (error) {
                    console.error("Erro ao apagar levantamento:", error);
                    Utils.showToast("Erro ao apagar levantamento.", "error");
                }
            }
        );
    },

    updateDebt: async (debt_id, event) => {
        Utils.showConfirmationModal(
            "Tem certeza que deseja atualizar este debt?",
            "Esta ação não pode ser desfeita.",
            async () => {
                try {
                    const request = await API.updateDebt(debt_id, "PAID"); 
                    if(!request.success) {
                        throw new Error(request.message);
                    }
                    const bt = event.target.closest('button');
                    if (bt && bt.classList.contains('verify-btn')) bt.remove();
                    Utils.showToast("Debt atualizado com sucesso!", "success");
                } catch (error) {
                    console.error("Erro ao atualizar debt:", error);
                    Utils.showToast("Erro ao atualizar debt.", "error");
                }
            }
        );
    },

    updateWithdrawal: async (withdrawal_id, event) => {
        Utils.showConfirmationModal(
            "Tem certeza que deseja atualizar este levantamento?",
            "Esta ação não pode ser desfeita.",
            async () => {
                try {
                    const request = await API.updateWithdrawal(withdrawal_id, "COMPLETED"); 
                    if(!request.success) {
                        throw new Error(request.message);
                    }
                    const bt = event.target.closest('button');
                    if (bt && bt.classList.contains('verify-btn')) bt.remove();
                    Utils.showToast("Levantamento atualizado com sucesso!", "success");
                } catch (error) {
                    console.error("Erro ao atualizar levantamento:", error);
                    Utils.showToast("Erro ao atualizar levantamento.", "error");
                }
            }
        );
    },

    verifyCasinoAccount: async (account_id, event) => {
        Utils.showConfirmationModal(
            "Tem certeza que deseja verificar esta conta de casino?",
            "Esta ação não pode ser desfeita.",
            async () => {
                try {
                    const request = await API.updateCasinoAccount(account_id, { status: "ACTIVE"}); 
                    if(!request.success) {
                        throw new Error(request.message);
                    }
                    const bt = event.target.closest('button');
                    if (bt && bt.classList.contains('verify-btn')) bt.remove();
                    Utils.showToast("Conta verificada com sucesso!", "success");
                } catch (error) {
                    console.error("Erro ao verificar conta de casino:", error);
                    Utils.showToast("Erro ao verificar conta de casino.", "error");
                }
            }
        );
    },

    addUserBonus: async (user_id, amount) => {
        try {
            const request = await API.addUserBonus(user_id, amount); 
            if(!request.success) {
                throw new Error(request.message);
            }
            Utils.showToast("Bónus adicionado com sucesso!", "success");
        } catch (error) {
            console.error("Erro ao adicionar bónus:", error);
            Utils.showToast("Erro ao adicionar bónus.", "error");
        }
    },

    showToast: (message, type) => {
        const toast = document.createElement("div");
        toast.className = `toast ${type}`;
        toast.innerText = message;
        document.body.appendChild(toast);
    
        setTimeout(() => {
            toast.classList.add("fade-out");
            setTimeout(() => toast.remove(), 500);
        }, 3000);
    },

    showConfirmationModal: (title, message, onConfirm) => {
        const modal = document.createElement("div");
        modal.className = "modal-overlay";
        modal.innerHTML = `
            <div class="modal-content">
                <h2>${title}</h2>
                <p>${message}</p>
                <div class="modal-actions">
                    <button id="confirm-btn" class="confirm">Confirmar</button>
                    <button id="cancel-btn" class="cancel">Cancelar</button>
                </div>
            </div>
        `;
        document.body.appendChild(modal);
    
        document.getElementById("confirm-btn").addEventListener("click", () => {
            onConfirm();
            modal.remove();
        });
    
        document.getElementById("cancel-btn").addEventListener("click", () => modal.remove());
    }
    
}

export default Utils