import Utils from './utils.js?v=2.1.17';
import API from './api.js?v=2.1.17';
import displayUsersTable from '../assets/components/admin/tables/usersTable.js';
import displayCasinoAccountsTable from '../assets/components/admin/tables/casinoAccountsTable.js';
import displayDebtsTable from '../assets/components/admin/tables/debtsTable.js';
import displayWithdrawalsTable from '../assets/components/admin/tables/withdrawalsTable.js';

let selectedAccounts = [];

document.addEventListener('DOMContentLoaded', async (event) => {
    const loginadmin = await Utils.findAdminSession();

    if(loginadmin) {
        const icons = document.querySelector('.sidebar').querySelectorAll('a');
        
        icons.forEach((icon, index) => {
            icon.addEventListener('click', () => {
                showPage(index);
            });
        });

        const searchInputs = document.querySelectorAll('.search-input');
        searchInputs.forEach(input => {
            input.addEventListener('keyup', function() {
                const tableId = this.getAttribute('data-table');
                const columnIndex = this.getAttribute('data-column');
                const value = this.value.toLowerCase();
                filterTable(tableId, columnIndex, value);
            });
        });

        buttonOpenPage();
        sidebarToggleAction();

        
        //displayChart(); //depois
        await displayUsersTable();
        displayCasinoAccountsTable();
        displayWithdrawalsTable();
        //displayUnseenEmails();
        await displayDebtsTable();


        //sendConfirmButtonEvent()
        //createCasinoAccountEvent()
        //confirmCreateAccountEvent();

        displayCasinoAccountForQuota();

        window.openOverlayAddSaldo = openOverlayAddSaldo;
        window.closeOverlayAddSaldo = closeOverlayAddSaldo;
        window.openOverlayCreateAccount = openOverlayCreateAccount;
        window.closeOverlayCreateAccount = closeOverlayCreateAccount;
        window.confirmAddSaldo = confirmAddSaldo;
        window.openOverlayQuota = openOverlayQuota;
        window.closeOverlayQuota = closeOverlayQuota;
        window.nextbuttonEvent = nextbuttonEvent;
        window.backbuttonEvent = backbuttonEvent;
        window.clearbuttonEvent = clearbuttonEvent;
        window.confirmingButtonEvent = confirmingButtonEvent;
    }
});

function showPage(index, instant = false) {
    const pages = document.querySelector('.content').querySelectorAll('main');
    pages.forEach((page, pageIndex) => {
        if (index !== pageIndex) {
            if(!instant) {
                page.style.animation = 'fadeOut 0.2s forwards';
                setTimeout(() => { page.classList.add('hidepage') }, 200);
            } else {
                page.classList.add('hidepage')
            };

        }
    });
        if(pages[index]) {

        sessionStorage.setItem('currentpageadmin', `${index}`);
            if(!instant) {
                setTimeout(() => { 
                    pages[index].classList.remove('hidepage');
                    pages[index].style.animation = 'fadeIn 0.5s forwards';
                }, 200)
            } else {
                pages[index].classList.remove('hidepage');
            }
        }
}

async function displayCasinoAccountForQuota() {
    const data = (await API.getCasinoAccounts()).result;
    const casinos = ["Betano", "Betclic", "Bwin", "ESC Online", "Placard"];

    function groupByProfileId(data) {
        return data.reduce((acc, account) => {
            const profileId = account.profile_id;

            if (!acc[profileId]) {
                acc[profileId] = {
                    profile_id: profileId,
                    user_id: account.user_id,
                    fullname: account.full_name,
                    accounts: {}
                };
            }

            // Mapear os casinos dentro de cada utilizador
            acc[profileId].accounts[account.casino_name] = {
                account_id: account.account_id,
                status: account.status
            };

            return acc;
        }, {});
    }
    
    const organizedData = groupByProfileId(data);


    const tableBody = document.getElementById('depositWithdrawTabel').querySelector('tbody');
    tableBody.innerHTML = '';

    Object.values(organizedData).forEach(({ profile_id, user_id, fullname, accounts }) => {
        const row = document.createElement('tr');

        // Criar o nome do utilizador
        const fullnameParts = fullname.split(' ');
        const firstName = fullnameParts[0];
        const lastName = fullnameParts[fullnameParts.length - 1];
        const displayName = `${firstName} ${lastName}`;

        const cellUsername = document.createElement('td');
        cellUsername.textContent = displayName;
        cellUsername.setAttribute('user_id', user_id);

        row.appendChild(cellUsername);

        // Criar células para cada casino
        casinos.forEach(casino => {
            const cellCasino1 = document.createElement('td');
            const cellCasino2 = document.createElement('td');

            const account = accounts[casino]; // Verifica se o utilizador tem conta nesse casino

            if (!account) {
                // Se não tiver conta, célula cinza
                cellCasino1.style.backgroundColor = "#cecece";
                cellCasino2.style.backgroundColor = "#cecece";
            } else {
                // Se tiver conta, definir cor conforme o status
                if (account.status === "INACTIVE") {
                    cellCasino1.style.backgroundColor = "#f5b9b9";
                    cellCasino2.style.backgroundColor = "#f5b9b9";
                } else if (account.status === "PENDING") {
                    cellCasino1.style.backgroundColor = "#f7f36d";
                    cellCasino2.style.backgroundColor = "#f7f36d";
                } else {
                    // Se não for PENDING nem ACTIVE, torna editável
                    cellCasino1.setAttribute('contenteditable', 'true');
                    cellCasino2.setAttribute('contenteditable', 'true');
                    cellCasino1.addEventListener('input', validateNumberInput);
                    cellCasino2.addEventListener('input', validateNumberInput);
                    cellCasino1.setAttribute('account_id', account.account_id);
                    cellCasino2.setAttribute('account_id', account.account_id);
                }
            }

            row.appendChild(cellCasino1);
            row.appendChild(cellCasino2);
        });

        tableBody.appendChild(row);
    });
}

function sidebarToggleAction() {
    const sidebar = document.querySelector('.sidebar');
    const sidebarToggle = document.getElementById('sidebarToggle');

    sidebarToggle.addEventListener('click', () => {
        sidebar.classList.toggle('active');
    });

    document.querySelectorAll('.sidebar a').forEach(link => {
        link.addEventListener('click', () => {
            sidebar.classList.remove('active');
        });
    });
}

function buttonOpenPage() {
    const pages = document.querySelector('.content').querySelectorAll('main');
    pages.forEach((page, index) => {
        const firstClass = page.classList[0];
        const enviosButton = document.querySelectorAll(`.${firstClass}-open`);
            enviosButton.forEach((button) => {
                button.addEventListener('click', () => {
                    showPage(index, pages);
                });
            });
    });
}

function filterTable(tableId, columnIndex, value) {
    const table = document.getElementById(tableId);
    const rows = table.getElementsByTagName('tbody')[0].getElementsByTagName('tr');
    
    for (let row of rows) {
        const cells = row.getElementsByTagName('td');
        const cellValue = cells[columnIndex].innerText.toLowerCase();
        row.style.display = cellValue.includes(value.toLowerCase()) ? '' : 'none';
    }
}

function deleteButtonEvent() {
    document.querySelectorAll('.table-card').forEach((table, index) => {
        table.querySelectorAll('.delete-btn').forEach(button => {
            button.addEventListener('click', function() {
                let ID = this.closest('tr').getAttribute('data-id') ||  this.closest('tr').querySelector('td').textContent;
                if (!ID) {
                    ID = "didn't work";
                }
                if (confirm('Are you sure you want to delete this entry?')) {
                    deleteUser(ID, this, index);
                }
            });
        });
    });
}

function withdrawConfirmButtonEvent() {
    const buttons = document.querySelectorAll('.wconfirm-btn')
    buttons.forEach((button, index) => {
        button.addEventListener('click', async function() {
            let ID = this.closest('tr').querySelector('td').textContent;
            await withdrawConfirm(ID);
        })
    }) 
}

async function withdrawConfirm(ID) {
    try {
        const token = localStorage.getItem('token');

        const response = await fetch('/api/admin/confirmarwithdraw', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Bearer ${token}`
            },
            body: JSON.stringify({ ID })
        });

        if (response.ok) {
            await displayWithdrawalsTable();
            sendConfirmButtonEvent();
            withdrawConfirmButtonEvent();
            deleteButtonEvent();
            verifyButtonEvent();
        } else {
            console.error('Error confirming withdraw:', response.statusText);
        }
    } catch (error) {
        console.error('Request error:', error);
    }
}

function sendConfirmButtonEvent() {
    const buttons = document.querySelectorAll('.sconfirm-btn')
    buttons.forEach((button, index) => {
        button.addEventListener('click', async function() {
            let ID = this.closest('tr').querySelector('td').textContent;
            await sendConfirm(ID);
        })
    }) 
}

function confirmCreateAccountEvent() {
    const button = document.querySelector('.button-confirm-create')
    button.addEventListener('click', async function() {
        closeOverlayCreateAccount();
        showLoadingWheel();
        try {
            
            var casino = document.getElementById('casino').value;
            var owner = document.getElementById('createcasinoacc-owner').value;
            var c_username = document.getElementById('createcasinoacc-username').value;
            var c_password = document.getElementById('createcasinoacc-password').value;
            var fullname = document.getElementById('createcasinoacc-fullname').value;
            var email = document.getElementById('createcasinoacc-email').value;
            var cc = document.getElementById('createcasinoacc-cc').value;
            var nif = document.getElementById('createcasinoacc-nif').value;
            var IBAN = document.getElementById('createcasinoacc-IBAN').value;

            const token = localStorage.getItem('token');
    
            const response = await fetch('/api/admin/addcasinoaccount', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'Authorization': `Bearer ${token}`
                },
                body: JSON.stringify({ owner, c_username, c_password, casino, IBAN, email, nif, cc, fullname })
            });
    
            if (response.ok) {
                hideLoadingWheel()
            } else {
                console.error('Error adding casino account:', response.statusText);
                hideLoadingWheel();
            }
        } catch (error) {
            console.error('Request error:', error);
        }
    })
}

async function sendConfirm(ID) {
    try {
        const token = localStorage.getItem('token');

        const response = await fetch('/api/admin/confirmarsend', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Bearer ${token}`
            },
            body: JSON.stringify({ ID })
        });

        if (response.ok) {
            await displayDebtsTable();
            sendConfirmButtonEvent()
            withdrawConfirmButtonEvent()
            deleteButtonEvent();
            verifyButtonEvent();
        } else {
            console.error('Error confirming send:', response.statusText);
        }
    } catch (error) {
        console.error('Request error:', error);
    }
}

function verifyButtonEvent() {
    document.querySelectorAll('.verify-btn').forEach(button => {
        button.addEventListener('click', function() {
            let ID = button.closest('tr').querySelector('td').textContent;
            const veryOverlay = document.createElement('div');
            veryOverlay.classList.add("overlay-2");
            veryOverlay.innerHTML = `
            <div class="alert-card">
                <p><strong>Marcar Como:</strong></p>
                <div class="buttons">
                    <button class="btn btn-yes" onclick="verify(2, ${ID})">Verificada</button>
                    <button class="btn btn-no" onclick="verify(0, ${ID})">Não Verificada</button>
                </div>
            </div>
            `        
            button.closest('main').appendChild(veryOverlay);
        });
    });
}

function openOverlayAddSaldo() {
    const overlay = document.getElementById('overlay-addsaldo');
    overlay.style.display = 'block';
}

function closeOverlayAddSaldo() {
    const overlay = document.getElementById('overlay-addsaldo');
    overlay.style.display = 'none';
}


function openOverlayCreateAccount() {
    const overlay = document.getElementById('overlay-createaccount');
    overlay.style.display = 'block';
}

function closeOverlayCreateAccount() {
    const overlay = document.getElementById('overlay-createaccount');
    overlay.style.display = 'none';
}

function confirmAddSaldo() {
    const saldoToAdd = parseFloat(saldoInput.value);

    if (isNaN(saldoToAdd) || saldoToAdd < 0) {
        alert('Digite um valor válido para adicionar saldo.');
        return;
    }

    if (selectedAccounts.length === 0) {
        alert('Selecione pelo menos uma conta para adicionar saldo.');
        return;
    }

    selectedAccounts.forEach(account => {
        addSaldo(account.ID, saldoToAdd);
    });

    // Clear selected accounts
    selectedAccounts = [];

    document.querySelectorAll('.checkbox-acc').forEach(checkbox => {
        if(checkbox.checked) {
            checkbox.checked = false;
        }
    })


    // Close the overlay
    closeOverlayAddSaldo();
}

function openOverlayQuota() {
    var overlay = document.getElementById('overlay-addquota');
    overlay.style.display = 'block';
}

function closeOverlayQuota() {
    var overlay = document.getElementById('overlay-addquota');
    overlay.style.display = 'none';
}
  
function formatDate2(dateStr) {
    var dateParts = dateStr.split("-");
    var day = dateParts[2].split("T")[0];
    var month = dateParts[1];
    return day + "-" + month;
}

window.onload = function() {

    let pageindex = parseInt(sessionStorage.getItem('currentpageadmin'))

    if (pageindex) {
        showPage(pageindex, true);
    } else {
        showPage(0, true);
    }
};


// async function getUsersData() {
//     const response = await API.getUsersData();
//     if (response.success) {
//         return response.result;
//     } else {
//         console.error('Erro ao obter dados dos usuários: ', response.message);
//     }
// }


// async function getGainsData() {
//     try {
//         const token = localStorage.getItem('token');

//         const response = await fetch('/api/admin/admingainsdata', {
//             method: 'GET',
//             headers: {
//                 'Content-Type': 'application/json',
//                 'Authorization': `Bearer ${token}`
//             }
//         });

//         if (response.ok) {
//             const data = await response.json();
//             if (data.empty) return null;
//             data.sort((a, b) => b.ID - a.ID)
//             return data;
//         } else {
//             console.error('Erro ao obter dados de gains:', response.statusText);
//         }
//     } catch (error) {
//         console.error('Erro na requisição:', error);
//     }
// }

// async function getUseenMails() {
//     try {
//         const token = localStorage.getItem('token');

//         const response = await fetch('/api/admin/unseenmails', {
//             method: 'GET',
//             headers: {
//                 'Content-Type': 'application/json',
//                 'Authorization': `Bearer ${token}`
//             }
//         });

//         if (response.ok) {
//             const mailsData = await response.json();

//             const allEmails = mailsData.flatMap(user => 
//                 user.emails.map(email => ({
//                     ...email,
//                     username: user.username
//                 }))
//             );

//             allEmails.sort((a, b) => new Date(b.date) - new Date(a.date) );

//             return allEmails;
//         } else {
//             console.error('Erro ao obter mails:', response.statusText);
//         }
//     } catch (error) {
//         console.error('Erro na requisição:', error);
//     }
// }

//display

// async function displayChart() {

//     const userData = await getUsersData();
//     const data = await getGainsData();
//     if(data) {
//         const data_batch = groupByBatch(data)

//         let total = 0.00;
//         for(let i = 0; i != data_batch.length; i++) {
//                 total += parseFloat(data_batch[i].totalValue);
//         }

//         let lastValue = data_batch[data_batch.length-1] ?  parseFloat(data_batch[data_batch.length-1].totalValue) : 0;

//         let beforeq = parseFloat(data_batch[data_batch.length-2].totalValue) 
//         let percentageq = ((lastValue-beforeq)/beforeq)*100 || 0;
//         let percentaget = (lastValue/total)*100;

//         if(isNaN(percentageq) || !isFinite(percentageq)) percentageq = 0.00;
//         if(isNaN(percentaget) || !isFinite(percentaget) || percentaget == -100) percentaget = 0.00;

//         const textQ = document.getElementById('percentg').classList
//         const textT = document.getElementById('percentt').classList

//         const contQ = document.getElementById('contQ').classList
//         const contT = document.getElementById('contT').classList

//         if(percentageq >= 0) {
//             contQ.add('positive')
//             textQ.add('positive')
//             document.getElementById('icon-percentg').classList.add('fa-arrow-up')
//         } else {
//             contQ.add("negative") 
//             textQ.add("negative") 
//             document.getElementById('icon-percentg').classList.add('fa-arrow-down')
//         }

//         if(percentaget >= 0) {
//             contT.add('positive')
//             textT.add('positive')
//             document.getElementById('icon-percentt').classList.add('fa-arrow-up')

//         } else {
//             contT.add("negative") 
//             textT.add("negative") 
//             document.getElementById('icon-percentt').classList.add('fa-arrow-down')
//         }
//         if(!lastValue) lastValue = 0.00;
//         if(!percentaget) percentaget = 0.00;
//         if(!percentageq) percentageq = 0.00;
//         if(!total) total = 0.00;

//         document.getElementById('percentt').textContent = (percentaget.toFixed(2)) + "%" 
//         document.getElementById('percentg').textContent = (percentageq.toFixed(2)) + "%" 
//         document.getElementById('quotalab').textContent = lastValue.toFixed(2) + " €"
//         document.getElementById('quotatotallab').textContent = total.toFixed(2) + " €"
//         var last8Data = getAllData(data_batch);

//         var chartOptions = {
//             scales: {
//               y: { 
//                 beginAtZero: true, 
//               }
//             }
//           };
        
//           // Get the canvas element
//           var ctx = document.getElementById('earningsChart').getContext('2d');
        
//           // Initialize datasets array with the 'Earnings' dataset
      
//           var colorget = [
//               "rgba(239,130,45,0.3)",
//               "rgba(226,0,12,0.3)",
//               "rgba(255,214,64,0.3)",
//               "rgba(217,171,71,0.3)",
//               "rgba(0,183,89,0.3)",
//               "rgba(29,32,37,0.3)"
//           ];
      
//           var colorgetp = [
//               "rgba(239,130,45,0.5)",
//               "rgba(226,0,12,0.5)",
//               "rgba(255,214,64,0.5)",
//               "rgba(217,171,71,0.5)",
//               "rgba(0,183,89,0.5)",
//               "rgba(29,32,37,0.5)"
//           ];
      
//           var datasets = [
//             {
//               label: 'Total',
//               data: last8Data.data,
//               backgroundColor: 'rgba(54, 162, 235, 1)', // Background color
//               borderColor: 'rgba(54, 162, 235, 1)', // Border color
//               borderWidth: 1
//             }
//           ];
//           Object.keys(last8Data.casinos).forEach((casino, index) => {
//               datasets.push({
//               label: casino,
//               data: last8Data.casinos[casino],
//               backgroundColor: colorgetp[index], 
//               borderColor: colorget[index],
//               borderWidth: 1
//             });
//           });
        
//           var earningsChart = new Chart(ctx, {
//             type: 'line',
//             data: {
//               labels: last8Data.labels,
//               datasets: datasets
//             },
//             options: chartOptions
//           });
//     } else {
//         const textQ = document.getElementById('percentg').classList
//         const textT = document.getElementById('percentt').classList
//         textT.add('positive')
//         textQ.add('positive')

//         const contQ = document.getElementById('contQ').classList
//         const contT = document.getElementById('contT').classList
//         contT.add('positive')
//         contQ.add('positive')

//         document.getElementById('percentt').textContent = "0%" 
//         document.getElementById('percentg').textContent = "0%" 
//         document.getElementById('quotalab').textContent = "0 €"
//         document.getElementById('quotatotallab').textContent = "0 €"
//     }

// }

function validateNumberInput(event) {
    const element = event.target;
    let inputValue = element.innerText;

    // Remove o símbolo " €" temporariamente para não interferir nas validações
    const hasEuroSymbol = inputValue.endsWith(' €');
    if (hasEuroSymbol) {
        inputValue = inputValue.slice(0, -2); // Remove os últimos dois caracteres (o espaço e o €)
    }

    // Troca a vírgula por um ponto
    inputValue = inputValue.replace(/,/g, '.');

    // Obtém a posição atual do cursor
    const selection = window.getSelection();
    const range = selection.getRangeAt(0);
    const cursorPosition = range.endOffset;

    // Remove caracteres não permitidos: apenas números, ponto ou sinal de negativo no início
    inputValue = inputValue.replace(/[^0-9.-]/g, '');

    // Garante que apenas um ponto decimal seja permitido e limita a duas casas decimais
    const parts = inputValue.split('.');
    if (parts.length > 2) {
        inputValue = parts[0] + '.' + parts.slice(1).join('');
    }

    if (parts.length === 2) {
        inputValue = parts[0] + '.' + parts[1].substring(0, 2); // Limita a duas casas decimais
    }

    // Garante que o sinal de negativo só apareça no início
    if (inputValue.includes('-') && inputValue.indexOf('-') > 0) {
        inputValue = inputValue.replace(/-/g, '');  // Remove todos os sinais de negativo que não estejam no início
    }

    // Adiciona o símbolo " €" ao final, se houver algum valor
    if (inputValue.trim() === '') {
        inputValue = '';  // Se não houver valor, não adiciona o símbolo " €"
    } else {
        inputValue += ' €';
    }

    // Atualiza o conteúdo da célula sem mover o cursor
    element.innerText = inputValue;

    // Restaura a posição do cursor, mas antes do " €" no final, se houver
    const newCursorPosition = inputValue.endsWith(' €') 
        ? Math.min(cursorPosition, inputValue.length - 2)  // Antes do " €"
        : cursorPosition;  // Caso não haja " €", mantém a posição atual

    if (element.innerText) {
        range.setStart(element.firstChild, newCursorPosition);
        range.setEnd(element.firstChild, newCursorPosition);
    }
    selection.removeAllRanges();
    selection.addRange(range);
}

async function nextbuttonEvent() {
    const depositwithdrawLines = document.getElementById('depositWithdrawTabel').querySelector("tbody").querySelectorAll('tr');
    document.getElementById('depositWithdrawTabel').style.display = "none";
    document.querySelector('.tables-container').style.display = "flex";
    document.querySelector('.back-button').style.display = "inline-block";
    document.querySelector('.seguinte-button').style.display = "none";
    document.querySelector('.clear-button').style.display = "none";
    document.querySelector('.confirm-button').style.display = "inline-block";

    // Obter todas as contas de casino
    const casinoAccountsData = (await API.getCasinoAccounts()).result;

    // Criar um objeto para contar quantas contas existem por casino
    const casinoTotals = casinoAccountsData.reduce((acc, account) => {
        if (account.status === "ACTIVE") {
            acc[account.casino_name] = (acc[account.casino_name] || 0) + 1;
        }
        return acc;
    }, {});

    // Ordenar os casinos pelo nome
    const sortedCasinoNames = Object.keys(casinoTotals).sort();
    const casinoAccountsNumber = sortedCasinoNames.map(name => casinoTotals[name]);

    // Preparar tabelas
    const clientSendsTable = document.getElementById('clientSendsTable').querySelector("tbody");
    clientSendsTable.innerHTML = '';

    const profitTable = document.getElementById('profitTable').querySelector("tbody");
    profitTable.innerHTML = '';

    let totalProfit = [];

    let casinoNames = document.getElementById('depositWithdrawTabel').querySelector("thead").querySelector("tr").querySelectorAll("th");

    depositwithdrawLines.forEach(line => {
        let values = line.querySelectorAll('td');
        
        let name = values[0] ? values[0].innerText.trim() : '';
        let ID = values[0].getAttribute("ID");
        
        let totalDeposit = 0;
        let totalWithdraw = 0;

        let c = 0;

        for (let i = 1; i < values.length; i += 2) {
            let depositValue = parseFloat(values[i].innerText.replace(' €', '').trim()) || 0;
            let withdrawValue = parseFloat(values[i + 1].innerText.replace('€', '').trim()) || 0;

            totalDeposit += depositValue;
            totalWithdraw += withdrawValue;

            totalProfit[c] = (totalProfit[c] || 0) + (withdrawValue - depositValue);
            c++;
        }

        const row = document.createElement('tr');

        const nameCell = document.createElement('td');
        nameCell.innerText = name;
        nameCell.setAttribute('ID', ID);
        row.appendChild(nameCell);

        const withdrawCell = document.createElement('td');
        withdrawCell.innerText = `${totalWithdraw.toFixed(2)}€`;
        row.appendChild(withdrawCell);

        clientSendsTable.appendChild(row);
    });

    totalProfit.forEach((profit, index) => {
        const row = document.createElement('tr');
    
        const CasinoName1 = document.createElement('td');
        CasinoName1.innerText = casinoNames[index + 1].innerText.trim();
        CasinoName1.setAttribute("accnum", casinoAccountsNumber[index]);
        CasinoName1.setAttribute("casino_id", index + 1);
        row.appendChild(CasinoName1);
    
        const CasinoValue = document.createElement('td');
        CasinoValue.innerText = profit.toFixed(2) + "€";
        row.appendChild(CasinoValue);

        const CasinoQuotaValue = document.createElement('td');
        CasinoQuotaValue.innerText = ((profit * 0.5) / casinoAccountsNumber[index]).toFixed(2) + "€";
        row.appendChild(CasinoQuotaValue);
    
        profitTable.appendChild(row);
    });
}
function backbuttonEvent() {
    document.getElementById('depositWithdrawTabel').style.display = "table";
    document.querySelector('.tables-container').style.display = "none";
    document.querySelector('.back-button').style.display = "none";
    document.querySelector('.confirm-button').style.display = "none";
    document.querySelector('.clear-button').style.display = "inline-block";
    document.querySelector('.seguinte-button').style.display = "inline-block";
}

function clearbuttonEvent() {
    const table = document.getElementById('depositWithdrawTabel')
    const lines = table.querySelectorAll('tbody tr');

    lines.forEach(line => {
       line.querySelectorAll("td").forEach((cell, index) => {
        if(index !== 0) cell.innerText = '';
       })
    });
}

async function confirmingButtonEvent() {
    try {
        const casinoTransactionsTable = document.getElementById('depositWithdrawTabel').querySelector("tbody").querySelectorAll("tr");
        const   casino_transactions = [];

        casinoTransactionsTable.forEach(row => {
            const cells = row.querySelectorAll("td");

            for (let i = 1; i < cells.length; i += 2) { // Percorre de 2 em 2 para pegar depósito e levantamento
                const depositCell = cells[i];
                const withdrawCell = cells[i + 1];

                const accountId = depositCell.getAttribute("account_id"); // Obtém o account_id da célula de depósito

                if (!accountId) continue; // Pula se não houver um account_id

                const depositValue = parseFloat(depositCell.innerText.replace('€', '').trim()) || 0;
                const withdrawValue = parseFloat(withdrawCell.innerText.replace('€', '').trim()) || 0;

                casino_transactions.push({
                    account_id: accountId,
                    deposit: depositValue,
                    withdraw: withdrawValue
                });
            }
        });
        console.log(casino_transactions)

        await API.setCycleTransactions(casino_transactions);
    } catch (error) {
        console.error(error);
    }
}

// async function displayUnseenEmails() {
//     const mailsData = await getUseenMails();
//     const tableBodyPending = document.getElementById('dataTable-mails').querySelector('tbody');
//     tableBodyPending.innerHTML = '';

//     if (!mailsData) {
//         return; 
//     }

//     mailsData.forEach((mail, index) => {
//         const row = document.createElement('tr');

//         const cellUsername = document.createElement('td');
//         cellUsername.textContent = mail.username;
//         row.appendChild(cellUsername);

//         const cellFrom = document.createElement('td');
//         cellFrom.textContent = mail.from;
//         row.appendChild(cellFrom);

//         const cellDate = document.createElement('td');
//         cellDate.textContent = mail.date;
//         row.appendChild(cellDate);

//         const cellSubject = document.createElement('td');
//         cellSubject.textContent = mail.subject;
//         row.appendChild(cellSubject);

//         const cellButton = document.createElement('td');
//         cellButton.innerHTML = `<button class="delete-btn">Delete</button>`
//         row.appendChild(cellButton);

//         tableBodyPending.appendChild(row);
//     })
// }

async function deleteUser(id, button, type) {
    try {
        const token = localStorage.getItem('token');

        const response = await fetch('/api/admin/deleteuser', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Bearer ${token}`
            },
            body: JSON.stringify({ id, type })
        });

        if (response.ok) {
            const row = button.closest('tr');
            row.parentNode.removeChild(row);
        } else {
            console.error('Error deleting user:', response.statusText);
        }
    } catch (error) {
        console.error('Request error:', error);
    }
}

async function addSaldo(ID, value) {
    const tableBody = document.getElementById('dataTable-accounts').querySelector('tbody');
    try {
        const token = localStorage.getItem('token');
        const response = await fetch('/api/admin/addsaldo', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Bearer ${token}`
            },
            body: JSON.stringify({ ID, value })
        });

        if (response.ok) {
            const accountRow = tableBody.querySelector(`tr[data-id="${ID}"]`);
                if (accountRow) {
                    const balanceCell = accountRow.querySelector('td:nth-child(4)'); // 3rd cell is the balance
                    if (balanceCell) {
                        
                        let currentBalance = parseFloat(balanceCell.textContent);
                        let saldoToAddFloat = parseFloat(value);

                        let newBalance = currentBalance + saldoToAddFloat;
                        balanceCell.textContent = newBalance.toFixed(2);
                    } else {
                        console.error('Balance cell not found.');
                    }
                }
        } else {
            console.error('Error adding user balance:', response.statusText);
        }
    } catch (error) {
        console.error('Request error:', error);
    }
}

function showLoadingWheel() {
    document.getElementById('loadingOverlay').style.animation = 'fadeIn 0.2s forwards';
    document.getElementById('loadingWheel').style.animation = 'fadeIn 0.2s forwards';
    setTimeout(() => { 
        document.getElementById('loadingOverlay').style.display = 'block';
        document.getElementById('loadingWheel').style.display = 'block';
    }, 200);
}

function hideLoadingWheel() {
    document.getElementById('loadingOverlay').style.animation = 'fadeOut 0.2s forwards';
    document.getElementById('loadingWheel').style.animation = 'fadeOut 0.2s forwards';
    setTimeout(() => { 
        document.getElementById('loadingOverlay').style.display = 'none';
        document.getElementById('loadingWheel').style.display = 'none';
    }, 200);
}