import Utils from './utils.js?v=2.0.16';
import API from './api.js?v=2.0.16';

const API_prefix = "/api";

document.addEventListener('DOMContentLoaded', async (event) => {
    showLoadingWheel()
    const login = await Utils.findSession();
        const icons = document.querySelector('.sidebar').querySelectorAll('a');

        icons.forEach((icon, index) => {
            icon.addEventListener('click', () => {
                showPage(index);
            });
        });

        const searchInputs = document.querySelectorAll('.search-input');
        searchInputs.forEach(input => {
            input.addEventListener('keyup', function() {
                const tableId = this.getAttribute('data-table');
                const columnIndex = this.getAttribute('data-column');
                const value = this.value.toLowerCase();
                filterTable(tableId, columnIndex, value);
            });
        });

        buttonOpenPage();
        logOutButtonsAction();
        sidebarToggleAction();
        casinocards();
        confirmWithdraw();

        //Displays
        await displayChart();
        await displayUserData();
        await displayCasinoAccounts();
        await displayPreferences();
        await displayDebts();
        await displayTransactions();

        window.openWithdrawOverlay = openWithdrawOverlay;
        window.updatePreferences = updatePreferences;
        window.discordConnectBtn = discordConnectBtn;
        window.closeWithdrawOverlay = closeWithdrawOverlay;
        window.hideNotification = hideNotification;

        hideLoadingWheel();
});

function getOldDate(daysago) {
    const today = new Date();
    today.setDate(today.getDate() - daysago);
    return today;
}

async function confirmWithdraw() {
    const confirmbutton = document.getElementById('confirm-withdraw');
    confirmbutton.addEventListener('click', async function() {
        closeWithdrawOverlay();
        showLoadingWheel();
        const value = document.getElementById('input-withdraw').value
        if(value <= 0) {
            hideLoadingWheel();
            document.getElementById('input-withdraw').value = ""
            return showNotification("Valor de levantamento inválido");
        }
        const userData = await getUserData();
        const sendsData = await getDebts();
        let isPaymentPending = false;
        for (let i = 0; i < (sendsData ? sendsData.length : 0); i++) {
            if (sendsData[i].state === "<div class='pending-payment'>Por Pagar</div>") {
                isPaymentPending = true;
                break;
            }
        }

        if(isPaymentPending) {
            showNotification("Tens envios por enviar para o Matias, verifica a aba envios e faz os devidos pagamentos para o número dele.");
        }
        else if(userData.balance && (value <= parseFloat(userData.balance))) {
            await Withdraw(value);
            await displayUserData();
            displayDebts();
            displayTransactions();
        } else {
            showNotification('Não tens dinheiro suficiente para fazer um levantamento de ' + value + "€.")
        }
        hideLoadingWheel();
    });
} 

function sidebarToggleAction() {
    const sidebar = document.querySelector('.sidebar');
    const sidebarToggle = document.getElementById('sidebarToggle');

    sidebarToggle.addEventListener('click', () => {
        sidebar.classList.toggle('active');
    });

    document.querySelectorAll('.sidebar a').forEach(link => {
        link.addEventListener('click', () => {
            sidebar.classList.remove('active');
        });
    });
}

function showPage(index, instant = false) {
    const pages = document.querySelector('.content').querySelectorAll('main');
    pages.forEach((page, pageIndex) => {
        if (index !== pageIndex) {
            if(!instant) {
                page.style.animation = 'fadeOut 0.2s forwards';
                setTimeout(() => { page.classList.add('hidepage') }, 200);
            } else {
                page.classList.add('hidepage')
            };

        }
    });
        if(pages[index]) {

        sessionStorage.setItem('currentpage', `${index}`);
            if(!instant) {
                setTimeout(() => { 
                    pages[index].classList.remove('hidepage');
                    pages[index].style.animation = 'fadeIn 0.5s forwards';
                }, 200)
            } else {
                pages[index].classList.remove('hidepage');
            }
        }
}

function buttonOpenPage() {
    const pages = document.querySelector('.content').querySelectorAll('main');
    pages.forEach((page, index) => {
        const firstClass = page.classList[0];
        const enviosButton = document.querySelectorAll(`.${firstClass}-open`);
            enviosButton.forEach((button) => {
                button.addEventListener('click', () => {
                    showPage(index);
                });
            });
    });
}

function logOutButtonsAction() {
    const buttons = document.querySelectorAll('.logout')
    buttons.forEach((button) => {
        button.addEventListener('click', () => {
            const token = localStorage.setItem('token', "");
            sessionStorage.setItem('currentpage', "0")
            window.location.href = "./login.html";
        });
    });
}

function filterTable(tableId, columnIndex, value) {
    const table = document.getElementById(tableId);
    const rows = table.getElementsByTagName('tbody')[0].getElementsByTagName('tr');
    
    for (let row of rows) {
        const cells = row.getElementsByTagName('td');
        const cellValue = cells[columnIndex].innerText.toLowerCase();
        row.style.display = cellValue.indexOf(value) > -1 ? '' : 'none';
    }
}

function casinocards() {
    const forms = document.querySelectorAll('.add-account-form')
    forms.forEach(form => {
        const nif = form.querySelector('#nif')
        const iban = form.querySelector('#iban')
        const cc = form.querySelector('#cc')
        const fullname = form.querySelector('#fullname')
        const inbanCont = form.querySelector('.file-input-container')
        nif.style.display = "none";
        iban.style.display = "none";
        cc.style.display = "none";
        fullname.style.display = "none";
        inbanCont.style.display = "none";
    });

    const addAccountButtons = document.querySelectorAll('.add-account-btn');
    const saveAccountButtons = document.querySelectorAll('.save-account-btn');
    const cardcasino = document.querySelectorAll('.card-casino');

    cardcasino.forEach(card => {
        card.addEventListener('click', function() {
            const content = card.querySelector('.card-content');
            const dropdownButton = card.closest('.dropdown-btn')
            if (card.classList.contains('expanded')) {
                card.classList.remove('expanded');
                content.style.maxHeight = '0';
                setTimeout(() => { card.querySelector('.add-account-form').style.display = "none" }, 500);
            } else {
                card.classList.add('expanded');
                content.style.maxHeight = (content.scrollHeight === 10 ? 0 : content.scrollHeight) + 'px';
                if(content.scrollHeight === 10) content.style.paddingBottom = "0px";
            }
        });

        const form = card.querySelector('.add-account-form');
        const switchInput = card.querySelector('#switch-account-creation');
        const password = form.querySelector('#password')
        const nif = form.querySelector('#nif')
        const iban = form.querySelector('#iban')
        const cc = form.querySelector('#cc')
        const fullname = form.querySelector('#fullname')
        const inbanCont = form.querySelector('.file-input-container')

        switchInput.addEventListener('change', (event) => {
            const content = card.querySelector('.card-content');
            if (event.target.checked) {
                password.style.display = "none";

                inbanCont.style.display = "inline-block";
                fullname.style.display = "flex";
                cc.style.display = "flex";
                nif.style.display = "flex";
                iban.style.display = "flex";
            } else {
                password.style.display = "flex";

                inbanCont.style.display = "none";
                fullname.style.display = "none";
                cc.style.display = "none";
                nif.style.display = "none";
                iban.style.display = "none";
            }
            content.style.maxHeight = content.scrollHeight + 'px';
        });
    });

    addAccountButtons.forEach(button => {
        button.addEventListener('click', function() {
            const cardContent = this.closest('.card-content');
            const form = cardContent.querySelector('.add-account-form');
            const isFormVisible = form.style.display === 'flex';

            form.style.display = isFormVisible ? 'none' : 'flex';

            // Recalcula a altura do card-content para acomodar o formulário de adicionar conta
            cardContent.style.maxHeight = cardContent.scrollHeight + 'px';
        });
    });

    saveAccountButtons.forEach((button, index) => {
        button.addEventListener('click', async function() {
            const form = this.closest('.add-account-form');
            const cardContent = this.closest('.card-content');
            const card = button.closest('.card-casino');
            const casino = index+1;

            const username = form.querySelector('#username').value;
            const nif = form.querySelector('#nif').value;
            const iban = form.querySelector('#iban').value;
            const cc = form.querySelector('#cc').value;
            const fullname = form.querySelector('#fullname').value;

            const ibanProof = form.querySelector('#iban-proof');
            const file = ibanProof.files[0];

            if (username
                && (nif.length === 9 && isPositiveInteger(nif)) 
                && isValidPortugueseIBAN(iban)
                && (isPositiveInteger(cc) && cc.length >= 8)
                && containsOnlyLettersAndSpaces(fullname)
                && (file && (file.type == "image/jpeg" || file.type == "image/png" || file.type == "application/pdf"))
                ) {
                    let result = await addNewCasinoAccount(username, "UNSETED", casino, iban, nif, cc, 1, fullname);
                    if (result) {
                        const newAccount = document.createElement('div');
                        newAccount.classList.add('account');
                        const verificationStatus = 'verificando';
                        newAccount.innerHTML = `
                            <div class="verification-status ${getVerificationClass(verificationStatus)}">
                                <span>${getVerificationText(verificationStatus)}</span>
                                <div class="status-indicator"></div>
                            </div>
                            <p><strong>Username:</strong> ${username}</p>
                            <p><strong>Nome:</strong> ${fullname}</p>
                            <p><strong>NIF:</strong> ${nif}</p>
                            <p><strong>IBAN:</strong> ${iban}</p>
                            <p><strong>Nº Cidadão:</strong> ${cc}</p>
                        `;
                        cardContent.querySelector(".accounts").appendChild(newAccount);
                        form.style.display = 'none';
                        form.reset();
                        cardContent.style.maxHeight = cardContent.scrollHeight + 'px';
                }
            } else {
                showNotification('Por favor, preencha todos os campos corretamente.');
            }
        });
    });
}

// async function addNewCasinoAccount(c_username, c_password, casino, IBAN, nif, cc, verified, fullname) {
//     try {
//         const response = await fetch('scripts/User/add_usercasinoaccount.php', {
//             method: 'POST',
//             headers: {
//                 'Content-Type': 'application/x-www-form-urlencoded'
//             },
//             body: new URLSearchParams({
//                 c_username: c_username,
//                 c_password: c_password,
//                 casino: casino,
//                 IBAN: IBAN,
//                 nif: nif,
//                 cc: cc,
//                 verified: verified,
//                 fullname: fullname
//             })
//         });

//         if (response.ok) {
//             const text = await response.text();
//             if (text === 'success') {
//                 return true;
//             } else {
//                 showNotification('Failed to create casino account, Error: ' + text);
//                 return false;
//             }
//         } else {
//             showNotification('Request failed. Returned status of ' + response.status);
//             return false;
//         }
//     } catch (error) {
//         showNotification('Request failed. Error: ' + error.message);
//         return false;
//     }
//     return true;
// } // desativar esta merda

function getVerificationClass(status) {
    switch (status) {
        case 'verificada':
            return 'verified';
        case 'verificando':
            return 'verifying';
        case 'não verificada':
            return 'unverified';
        default:
            return '';
    }
}

function getVerificationText(status) {
    switch (status) {
        case 'verificada':
            return 'Verificada';
        case 'verificando':
            return 'Em Verificação';
        case 'não verificada':
            return 'Não Verificada';
        default:
            return '';
    }
}

function discordConnectBtn() {
    window.location.href = "https://discord.com/oauth2/authorize?client_id=1256276816117891163&response_type=code&redirect_uri=https%3A%2F%2Fbci.carpete.pt%2Fapi%2Fupdate%2Fdiscordaccount&scope=identify+email";
}

window.onload = function() {
    let pageindex = parseInt(sessionStorage.getItem('currentpage'))
    if (pageindex) {
        showPage(pageindex, true);
    } else {
        showPage(0, true);
    }
};



//FEITO///////////////////////////// 

async function getProfits() {
    const response = await API.getProfits();

    if (response.success) {
        return response.result;
    } else {
        console.error('Erro ao obter profits do usuário:', response.message);
    }
}

async function getUserData() {
    const response = await API.getUserData();
    if (response.success) {
        return response.result;
    } else {
        console.error('Erro ao obter dados do usuário:', response.message);
    }
}

async function getDebts() {
    const response = await API.getUserDebts();
    if (response.success) {
        return response.result;
    } else {
        console.error('Erro ao obter dívidas do usuário:', response.message);
    }
}

async function getTransactions() {
    const response = await API.getTransactions();
    if (response.success) {
        return response.result;
    } else {
        console.error('Erro ao obter transações do usuário:', response.message);
    }
}

async function getPreferences() {
    const response = await API.getPreferences();
    if (response.success) {
        return response.result;
    } else {
        console.error('Erro ao obter preferencias do usuário:', response.message);
    }
}

async function getCasinoAccounts() {
    const response = await API.getUserCasinoAccounts();
    if (response.success) {
        return response.result;
    } else {
        console.error('Erro ao obter contas de casino do usuário:', response.message);
    }
}

async function getChartData() {
    const response = await API.getChartData();
    if (response.success) {
        return response.result;
    } else {
        console.error('Erro ao obter gráfico do usuário:', response.message);
    }
}

async function displayUserData() {
    const data = await getUserData();
    const balanceTexts = document.querySelectorAll('#balance-text');
    balanceTexts.forEach(element => {
        element.textContent = data.balance + "€";
    })
    const email = document.querySelectorAll('#useremail');
    email.forEach(element => {
        element.textContent = data.email;
    })
    const fullname = document.querySelectorAll('#userfullname');
    fullname.forEach(element => {
        element.textContent = data.fullname;
    })
    const date = document.querySelectorAll('#userdate');
    date.forEach(element => {
        element.textContent = formatDate(data.created_at);
    })
    const phone = document.querySelectorAll('#userphone');
    phone.forEach(element => {
        element.textContent = data.phone;
    })
}

async function displayDebts() {
    const data = await getDebts();

    if(data) {
        data.sort((a, b) => b.debt_id - a.debt_id);

        const tableBodyPending = document.getElementById('dataTable-pending').querySelector('tbody');
        tableBodyPending.innerHTML = '';

        data.forEach(debt => {
            const row = document.createElement('tr');

            const cellValue = document.createElement('td');
            cellValue.textContent = debt.amount + "€";
            row.appendChild(cellValue);

            const cellDate = document.createElement('td');
            cellDate.textContent = formatDate(debt.created_at);
            row.appendChild(cellDate);

            const cellState = document.createElement('td');
            cellState.innerHTML = capitalizeFirstLetter(debt.status);
            row.appendChild(cellState);

            tableBodyPending.appendChild(row);
        });
    }
}

async function displayTransactions() {
    const data = await getTransactions();
    if(data) {
        data.sort((a, b) => b.transaction_id - a.transaction_id);

        const tableBodyTransactions = document.getElementById('dataTable-transactions').querySelector('tbody');
        tableBodyTransactions.innerHTML = '';

        data.forEach(transaction => {
            const row = document.createElement('tr');

            const cellValue = document.createElement('td');
            if(transaction.transaction_type != "WITHDRAWAL") {
                cellValue.textContent = "+" + transaction.amount + "€";
                cellValue.style.color = "#0c8227";
            } else {
                cellValue.textContent = "-" + transaction.amount + "€";
                cellValue.style.color = "#e71a0c";  
            }
            row.appendChild(cellValue);

            const cellType = document.createElement('td');
            cellType.textContent = capitalizeFirstLetter(transaction.transaction_type);
            row.appendChild(cellType);

            const cellDate = document.createElement('td');
            const formattedDate = formatDate(transaction.created_at);
            cellDate.textContent = formattedDate;
            row.appendChild(cellDate);

            tableBodyTransactions.appendChild(row);

        });
    }
}

async function displayPreferences() {
    const preferences = await getPreferences();
        if(preferences) {
        preferences.forEach(preference => {
            document.getElementById(preference.preference_key).checked = preference.preference_value;
        })
    }
}

async function displayCasinoAccounts() {
    const accounts = await getCasinoAccounts();
    if(accounts) {
        const casinocards = document.querySelectorAll('.card-casino')
        casinocards.forEach(card => {
            const casinoname = card.querySelector('.casino-name').textContent;
            card = card.querySelector('.accounts')
            accounts.forEach(account => {
                if(account.casino_name === casinoname) {
                    const accdiv = document.createElement('div');
                    accdiv.classList.add("account")

                    accdiv.innerHTML = `
                        <div class="verification-status ${account.status}">
                            <div class="status-indicator"></div>
                            <span>${account.status}</span>
                        </div>
                        <div class="account-data">
                            <p><strong>Nome do Titular:</strong> ${getFirstAndLastName(account.full_name)}</p>
                            <p><strong>Cartão de Cidadão:</strong> ${account.numero_cartao_cidadao}</p>
                            <p><strong>NIF:</strong> ${account.nif}</p>
                            <p><strong>IBAN:</strong> ${account.IBAN}</p>
                        <div>`
                    card.appendChild(accdiv);
                }
            });
        })
    }
}

const getFirstAndLastName = (fullName) => {
    const words = fullName.trim().split(/\s+/); // Divide pelo espaço, removendo espaços extras
    const first = words[0];
    const last = words.length > 1 ? words[words.length - 1] : first; // Se só houver um nome, retorna o mesmo
    return first + " " +last;
};

async function displayChart() { //ACABAR


    const userProfits = await getProfits();
    const ChartData = await getChartData();

    if(ChartData && userProfits && userProfits.casino_profit > 0) {

        function groupByCycleId(data) {
            return data.reduce((acc, item) => {
                if (!acc[item.cycle_id]) {
                    acc[item.cycle_id] = {
                        date: item.date,
                        casinos: []
                    };
                }
                acc[item.cycle_id].casinos.push({
                    casino_name: item.casino_name,
                    profit: item.profit
                });
        
                return acc;
            }, {});
        }

        const formattedData = groupByCycleId(ChartData)
        

        const textQ = document.getElementById('percentg').classList
        const textT = document.getElementById('percentt').classList
        const contQ = document.getElementById('contQ').classList
        const contT = document.getElementById('contT').classList

        const totalProfit = (parseFloat(userProfits.casino_profit) + parseFloat(userProfits.bonus_profit)).toFixed(2);
        const cycleIds = Object.keys(formattedData).map(Number).sort((a, b) => a - b); // Ordena os cycle_ids
        const lastCycleId = cycleIds[cycleIds.length - 1]; // Último cycle_id
        const prevCycleId = cycleIds.length > 1 ? cycleIds[cycleIds.length - 2] : null; // Penúltimo cycle_id (se existir)
        
        const lastProfit = (formattedData[lastCycleId].casinos.reduce((sum, casino) => sum + parseFloat(casino.profit), 0)).toFixed(2);
        const prevProfit = prevCycleId ? formattedData[prevCycleId].casinos.reduce((sum, casino) => sum + parseFloat(casino.profit), 0) : null;
        
        let percentIncrease;
        let totalpercentIncrease;
        if(lastProfit && lastProfit >= 0) {
            if (prevProfit === null) {
                percentIncrease = 100; // Se não houver penúltimo cycle, assume 100%
            } else if (prevProfit === 0) {
                percentIncrease = lastProfit > 0 ? 100 : 0; // Se o anterior foi 0 e o novo for > 0, assume 100%, senão 0%
            } else {
                percentIncrease = (((lastProfit - prevProfit) / prevProfit) * 100).toFixed(2); // Fórmula de aumento percentual
            }
            totalpercentIncrease = (100*lastProfit/totalProfit).toFixed(2);
        } else {
            percentIncrease = 0.00;
            totalpercentIncrease = 0.00;
        }
        

        if(percentIncrease >= 0) {
            contQ.add('positive')
            textQ.add('positive')
            document.getElementById('icon-percentg').classList.add('fa-arrow-up')
        } else {
            contQ.add("negative") 
            textQ.add("negative") 
            document.getElementById('icon-percentg').classList.add('fa-arrow-down')
        }

        contT.add('positive')
        textT.add('positive')
        document.getElementById('icon-percentt').classList.add('fa-arrow-up')    

        document.getElementById('percentt').textContent = totalpercentIncrease + "%" 
        document.getElementById('percentg').textContent = percentIncrease + "%" 
        document.getElementById('quotalab').textContent =  lastProfit +  " €"
        document.getElementById('quotatotallab').textContent = totalProfit + " €"

        
        // 🎨 Definir cores fixas para os casinos
        const casinoColors = {
            "Betano": "rgba(239,130,45,0.7)",
            "Betclic": "rgba(226,0,12,0.7)",
            "Bwin": "rgba(255,214,64,0.7)",
            "ESC online": "rgba(217,171,71,0.7)",
            "Placard": "rgba(29,32,37,0.7)",
            "Solverde": "rgba(0,183,89,0.7)"
        };

        const casinoBorderColors = {
            "Betano": "rgba(239,130,45,0.3)",
            "Betclic": "rgba(226,0,12,0.3)",
            "Bwin": "rgba(255,214,64,0.3)",
            "ESC online": "rgba(217,171,71,0.3)",
            "Placard": "rgba(29,32,37,0.3)",
            "Solverde": "rgba(0,183,89,0.3)"
        };

        // Obter os últimos 8 cycle_ids (ou menos, se não houver 8)
        const lastCycleIds = cycleIds.slice(-10);

        // Criar um conjunto de todos os casinos únicos
        const casinos = new Set();
        lastCycleIds.forEach(cycleId => {
            formattedData[cycleId].casinos.forEach(casino => {
                casinos.add(casino.casino_name);
            });
        });

        // Preparar labels (datas) e datasets
        const labels = lastCycleIds.map(cycleId => {
            const date = new Date(formattedData[cycleId].date);
            return `${date.getDate().toString().padStart(2, '0')}/${(date.getMonth() + 1).toString().padStart(2, '0')}`;
        });

        const datasets = Array.from(casinos).map(casinoName => {
            const data = lastCycleIds.map(cycleId => {
                const casinoData = formattedData[cycleId].casinos.find(casino => casino.casino_name === casinoName);
                return casinoData ? parseFloat(casinoData.profit) : 0;  // Default para 0 se não houver dados para esse casino
            });

            return {
                label: casinoName,
                data: data,
                backgroundColor: casinoColors[casinoName] || "rgba(100,100,100,0.7)", // Cor padrão caso o casino não esteja no mapeamento
                borderColor: casinoBorderColors[casinoName] || "rgba(100,100,100,1)",
                borderWidth: 1
            };
        });

        // Adicionar dataset para o total de cada cycle
        const totalData = lastCycleIds.map(cycleId => {
            return formattedData[cycleId].casinos.reduce((sum, casino) => sum + parseFloat(casino.profit), 0);
        });

        datasets.push({
            label: 'Total',
            data: totalData,
            backgroundColor: 'rgba(54, 162, 235, 1)', // Background color
            borderColor: 'rgba(54, 162, 235, 1)', // Border color
            borderWidth: 1
        });

        // Configuração do gráfico
        var chartOptions = {
            scales: {
                y: { 
                    beginAtZero: true, 
                }
            }
        };

        // Criar o gráfico
        var ctx = document.getElementById('earningsChart').getContext('2d');
        var earningsChart = new Chart(ctx, {
            type: 'line',
            data: {
                labels: labels,
                datasets: datasets
            },
            options: chartOptions
        });

    } else {
        const textQ = document.getElementById('percentg').classList
        const textT = document.getElementById('percentt').classList
        textT.add('positive')
        textQ.add('positive')

        const contQ = document.getElementById('contQ').classList
        const contT = document.getElementById('contT').classList
        contT.add('positive')
        contQ.add('positive')

        if(userProfits.bonus_profit > 0) {
            document.getElementById('percentt').textContent = "100.00%" 
            document.getElementById('percentg').textContent = "0.00%" 
            document.getElementById('quotalab').textContent = "0 €"
            document.getElementById('quotatotallab').textContent = userProfits.bonus_profit+ " €"
        } else {
            document.getElementById('percentt').textContent = "0.00%" 
            document.getElementById('percentg').textContent = "0.00%" 
            document.getElementById('quotalab').textContent = "0 €"
            document.getElementById('quotatotallab').textContent = "0 €"
        }

// Configuração do gráfico
var chartOptions = {
    scales: {
        y: { 
            beginAtZero: true, 
        }
    }
};

// Criar o gráfico vazio
var ctx = document.getElementById('earningsChart').getContext('2d');
var earningsChart = new Chart(ctx, {
    type: 'line', // Tipo de gráfico
    data: {
        labels: [], // Sem rótulos (sem dados no eixo X)
        datasets: [] // Sem datasets (sem dados no gráfico)
    },
    options: chartOptions,
    // Quando o gráfico é desenhado, desenhe a mensagem também
    plugins: [{
        afterDraw: function(chart) {
            // Se não houver dados, desenha a mensagem no centro
            if (chart.data.datasets.length === 0 || chart.data.labels.length === 0) {
                var ctx = chart.ctx;
                var width = chart.width;
                var height = chart.height;
                var fontSize = 18; // Tamanho da fonte

                // Estilo da fonte e cor do texto
                ctx.fillStyle = 'rgba(0, 0, 0, 0.7)'; // Cor do texto
                ctx.font = fontSize + 'px "Helvetica", sans-serif'; // Fonte clean e simples
                ctx.textAlign = 'center';
                ctx.textBaseline = 'middle';

                // Texto a ser exibido
                var message = 'Sem dados disponíveis';

                // Desenha o texto no centro do gráfico
                ctx.fillText(message, width / 2, height / 2);
            }
        }
    }]
});


    }

}



async function Withdraw(value) {
    const response = await API.withdraw(value);
    if (response.success) {
        return response.result;
    } else {
        console.error('Erro ao fazer withdraw:', response.message);
    }
}

async function updatePreferences() {
    const preferences = {
        email_notifications: document.getElementById('email_notifications').checked?1:0,
        discord_notifications: document.getElementById('discord_notifications').checked?1:0,
        whatsapp_notifications: document.getElementById('whatsapp_notifications').checked?1:0,
        debts: document.getElementById('debts').checked?1:0,
        withdrawals: document.getElementById('withdrawals').checked?1:0,
        received_money: document.getElementById('received_money').checked?1:0,
        bci_updates: document.getElementById('bci_updates').checked?1:0,
    }

    await API.updatePreferences(preferences);
}

///USEFUL FUNCTIONS:

async function openWithdrawOverlay() {
    const transactionsData = await getTransactions();
    const transactionWithOrigin3 = transactionsData.find(transaction => transaction.origin === "Levantamento");
    if(transactionWithOrigin3 && !isEarlierThan(transactionWithOrigin3.created_at, getOldDate(7))) {
        return showNotification("Apenas podes realizar um levantamento por semana.");
    }
    document.querySelector(".overlay-withdraw").style.animation = 'fadeIn 0.2s forwards';
    setTimeout(() => {
        document.querySelector(".overlay-withdraw").style.display = 'flex';
    }, 200); // Small delay to ensure the display change is applied
}

function closeWithdrawOverlay() {
    document.querySelector(".overlay-withdraw").style.animation = 'fadeOut 0.2s forwards';
    setTimeout(() => {
        document.querySelector(".overlay-withdraw").style.display = 'none';
    }, 200); // Wait for the fade-out transition to complete
}

function showNotification(message) {
    const overlay = document.getElementById('notificationOverlay');
    const messageBox = document.getElementById('notificationMessage');
    messageBox.textContent = message;

    overlay.style.animation = 'fadeIn 0.2s forwards';
    setTimeout(() => {
        overlay.style.display = 'flex';
    }, 200); // Small delay to ensure the display change is applied
}

function hideNotification() {
    const overlay = document.getElementById('notificationOverlay');
    overlay.style.animation = 'fadeOut 0.2s forwards';
    setTimeout(() => {
        overlay.style.display = 'none';
    }, 200); // Wait for the fade-out transition to complete
}

function showLoadingWheel() {
    document.getElementById('loadingOverlay').style.animation = 'fadeIn 0.2s forwards';
    document.getElementById('loadingWheel').style.animation = 'fadeIn 0.2s forwards';
    setTimeout(() => { 
        document.getElementById('loadingOverlay').style.display = 'block';
        document.getElementById('loadingWheel').style.display = 'block';
    }, 200);
}
  
function hideLoadingWheel() {
    document.getElementById('loadingOverlay').style.animation = 'fadeOut 0.2s forwards';
    document.getElementById('loadingWheel').style.animation = 'fadeOut 0.2s forwards';
    setTimeout(() => { 
        document.getElementById('loadingOverlay').style.display = 'none';
        document.getElementById('loadingWheel').style.display = 'none';
    }, 200);
}

function isEarlierThan(date1, date2) {
    const d1 = new Date(date1);
    const d2 = new Date(date2);

    // Normalize both dates by converting them to local time and setting time to midnight (00:00:00)
    d1.setHours(0, 0, 0, 0);
    d2.setHours(0, 0, 0, 0);

    // Compare just the date (ignoring the time zone differences)
    return d1 < d2;
}
function containsOnlyLettersAndSpaces(str) {
    return /^[A-Za-zÀ-ÖØ-öø-ÿĀ-žẀ-ẅỲ-ỹ\s]+$/.test(str);
}

function isPositiveInteger(str) {
    return /^\d+$/.test(str);
}

function isValidPortugueseIBAN(iban) {
    // Remove spaces and convert to uppercase
    iban = iban.replace(/\s+/g, '').toUpperCase();

    // Check if the IBAN starts with "PT" and has a length of 25 characters
    if (!iban.startsWith("PT") || iban.length !== 25) {
        return false;
    }

    // Check the general structure
    if (!/^[A-Z0-9]+$/.test(iban)) {
        return false;
    }

    // Move the first four characters to the end of the string
    const rearrangedIban = iban.slice(4) + iban.slice(0, 4);

    // Replace each letter with its corresponding number (A = 10, B = 11, ..., Z = 35)
    const numericIban = rearrangedIban.replace(/[A-Z]/g, match => match.charCodeAt(0) - 55);

    // Perform the mod-97 operation
    let remainder = numericIban;
    while (remainder.length > 2) {
        const block = remainder.slice(0, 9);  // Take the first 9 digits
        remainder = (parseInt(block, 10) % 97) + remainder.slice(block.length);
    }

    return parseInt(remainder, 10) % 97 === 1;
}

function formatDate(dateStr) {
    var dateParts = dateStr.split("-");
    var day = `${parseInt(dateParts[2].split("T")[0])}`;
    if(day.length === 1) day = "0" + day;
    var month = dateParts[1];
    var year = dateParts[0];
    return day + "-" + month + "-" + year;
}

function formatDate2(dateStr) {
    var dateParts = dateStr.split("-");
    var day = `${parseInt(dateParts[2].split("T")[0])}`;
    if(day.length === 1) day = "0" + day;
    var month = dateParts[1];
    return day + "-" + month;
}

function capitalizeFirstLetter(str) {
    return str.charAt(0).toUpperCase() + str.slice(1).toLowerCase();
}
